diff --git a/blackout/blackout.php b/blackout/blackout.php
index 94e081ce..1c34862b 100644
--- a/blackout/blackout.php
+++ b/blackout/blackout.php
@@ -9,12 +9,12 @@
* About
* =====
*
- * This plugin will allow you to enter a date/time period during which
+ * This addon will allow you to enter a date/time period during which
* all your ~friendica visitors from the web will be redirected to a page
* you can configure in the admin panel as well.
*
* Calls to the API and the communication with other ~friendica nodes is
- * not effected from this plugin.
+ * not effected from this addon.
*
* If you enter a period the current date would be affected none of the
* currently logged in users will be effected as well. But if they log
@@ -88,7 +88,7 @@ function blackout_redirect ($a, $b) {
}
}
-function blackout_plugin_admin(&$a, &$o) {
+function blackout_addon_admin(&$a, &$o) {
$mystart = Config::get('blackout','begindate');
if (! is_string($mystart)) { $mystart = "YYYY-MM-DD:hhmm"; }
$myend = Config::get('blackout','enddate');
@@ -112,7 +112,7 @@ function blackout_plugin_admin(&$a, &$o) {
$o = '
Please double check that the current settings for the blackout. Begin will be '.$mystart.' and it will end '.$myend.'.
' . t ('This plugin looks in posts for the words/text you specify below, and collapses any content containing those keywords so it is not displayed at inappropriate times, such as sexual innuendo that may be improper in a work setting. It is polite and recommended to tag any content containing nudity with #NSFW. This filter can also match any other word/text you specify, and can thereby be used as a general purpose content filter.') . '
';
+ $s .= '
' . t ('This addon looks in posts for the words/text you specify below, and collapses any content containing those keywords so it is not displayed at inappropriate times, such as sexual innuendo that may be improper in a work setting. It is polite and recommended to tag any content containing nudity with #NSFW. This filter can also match any other word/text you specify, and can thereby be used as a general purpose content filter.') . '
';
$s .= '';
$s .= '';
$s .= '';
diff --git a/numfriends/numfriends.php b/numfriends/numfriends.php
index 9e3463c3..5d6575c4 100644
--- a/numfriends/numfriends.php
+++ b/numfriends/numfriends.php
@@ -10,8 +10,8 @@ use Friendica\Core\PConfig;
function numfriends_install() {
- Addon::registerHook('plugin_settings', 'addon/numfriends/numfriends.php', 'numfriends_settings');
- Addon::registerHook('plugin_settings_post', 'addon/numfriends/numfriends.php', 'numfriends_settings_post');
+ Addon::registerHook('addon_settings', 'addon/numfriends/numfriends.php', 'numfriends_settings');
+ Addon::registerHook('addon_settings_post', 'addon/numfriends/numfriends.php', 'numfriends_settings_post');
logger("installed numfriends");
}
@@ -19,15 +19,13 @@ function numfriends_install() {
function numfriends_uninstall() {
- Addon::unregisterHook('plugin_settings', 'addon/numfriends/numfriends.php', 'numfriends_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/numfriends/numfriends.php', 'numfriends_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/numfriends/numfriends.php', 'numfriends_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/numfriends/numfriends.php', 'numfriends_settings_post');
logger("removed numfriends");
}
-
-
/**
*
* Callback from the settings post function.
@@ -36,7 +34,6 @@ function numfriends_uninstall() {
* and if so set our configuration setting for this person.
*
*/
-
function numfriends_settings_post($a,$post) {
if(! local_user() || (! x($_POST,'numfriends-submit')))
return;
@@ -48,13 +45,10 @@ function numfriends_settings_post($a,$post) {
/**
*
- * Called from the Plugin Setting form.
+ * Called from the Addon Setting form.
* Add our own settings info to the page.
*
*/
-
-
-
function numfriends_settings(&$a, &$s)
{
if (! local_user()) {
diff --git a/openstreetmap/openstreetmap.php b/openstreetmap/openstreetmap.php
index d61d0020..29ada924 100644
--- a/openstreetmap/openstreetmap.php
+++ b/openstreetmap/openstreetmap.php
@@ -163,7 +163,7 @@ function openstreetmap_generate_map(&$a, &$b)
}
-function openstreetmap_plugin_admin(&$a, &$o)
+function openstreetmap_addon_admin(&$a, &$o)
{
$t = get_markup_template("admin.tpl", "addon/openstreetmap/");
$tmsserver = Config::get('openstreetmap', 'tmsserver');
@@ -192,7 +192,7 @@ function openstreetmap_plugin_admin(&$a, &$o)
]);
}
-function openstreetmap_plugin_admin_post(&$a)
+function openstreetmap_addon_admin_post(&$a)
{
$urltms = ((x($_POST, 'tmsserver')) ? notags(trim($_POST['tmsserver'])) : '');
$urlnom = ((x($_POST, 'nomserver')) ? notags(trim($_POST['nomserver'])) : '');
diff --git a/pageheader/pageheader.php b/pageheader/pageheader.php
index 0a293103..96ad3630 100644
--- a/pageheader/pageheader.php
+++ b/pageheader/pageheader.php
@@ -12,16 +12,16 @@ use Friendica\Core\Config;
function pageheader_install() {
Addon::registerHook('page_content_top', 'addon/pageheader/pageheader.php', 'pageheader_fetch');
- Addon::registerHook('plugin_settings', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings');
- Addon::registerHook('plugin_settings_post', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings_post');
+ Addon::registerHook('addon_settings', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings');
+ Addon::registerHook('addon_settings_post', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings_post');
}
function pageheader_uninstall() {
Addon::unregisterHook('page_content_top', 'addon/pageheader/pageheader.php', 'pageheader_fetch');
- Addon::unregisterHook('plugin_settings', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/pageheader/pageheader.php', 'pageheader_addon_settings_post');
// hook moved, uninstall the old one if still there.
Addon::unregisterHook('page_header', 'addon/pageheader/pageheader.php', 'pageheader_fetch');
diff --git a/planets/planets.php b/planets/planets.php
index 794d1f02..04fb72ca 100644
--- a/planets/planets.php
+++ b/planets/planets.php
@@ -1,7 +1,7 @@
* Author: Tony Baldwin
@@ -13,7 +13,7 @@ function planets_install() {
/**
*
- * Our demo plugin will attach in three places.
+ * Our demo addon will attach in three places.
* The first is just prior to storing a local post.
*
*/
@@ -22,14 +22,14 @@ function planets_install() {
/**
*
- * Then we'll attach into the plugin settings page, and also the
+ * Then we'll attach into the addon settings page, and also the
* settings post hook so that we can create and update
* user preferences.
*
*/
- Addon::registerHook('plugin_settings', 'addon/planets/planets.php', 'planets_settings');
- Addon::registerHook('plugin_settings_post', 'addon/planets/planets.php', 'planets_settings_post');
+ Addon::registerHook('addon_settings', 'addon/planets/planets.php', 'planets_settings');
+ Addon::registerHook('addon_settings_post', 'addon/planets/planets.php', 'planets_settings_post');
logger("installed planets");
}
@@ -46,8 +46,8 @@ function planets_uninstall() {
*/
Addon::unregisterHook('post_local', 'addon/planets/planets.php', 'planets_post_hook');
- Addon::unregisterHook('plugin_settings', 'addon/planets/planets.php', 'planets_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/planets/planets.php', 'planets_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/planets/planets.php', 'planets_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/planets/planets.php', 'planets_settings_post');
logger("removed planets");
@@ -62,7 +62,7 @@ function planets_post_hook($a, &$item) {
* An item was posted on the local system.
* We are going to look for specific items:
* - A status post by a profile owner
- * - The profile owner must have allowed our plugin
+ * - The profile owner must have allowed our addon
*
*/
@@ -123,7 +123,7 @@ function planets_settings_post($a,$post) {
/**
*
- * Called from the Plugin Setting form.
+ * Called from the Addon Setting form.
* Add our own settings info to the page.
*
*/
@@ -158,7 +158,7 @@ function planets_settings(&$a,&$s) {
$s .= '
';
$s .= '
' . t('Planets Settings') . '
';
$s .= '
';
- $s .= '';
+ $s .= '';
$s .= '';
$s .= '
';
diff --git a/pledgie/pledgie.php b/pledgie/pledgie.php
index 27897e52..2b75268b 100644
--- a/pledgie/pledgie.php
+++ b/pledgie/pledgie.php
@@ -12,14 +12,14 @@ use Friendica\Core\Config;
function pledgie_install() {
Addon::registerHook('page_end', 'addon/pledgie/pledgie.php', 'pledgie_active');
- Addon::registerHook('plugin_settings', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings');
- Addon::registerHook('plugin_settings_post', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings_post');
+ Addon::registerHook('addon_settings', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings');
+ Addon::registerHook('addon_settings_post', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings_post');
}
function pledgie_uninstall() {
Addon::unregisterHook('page_end', 'addon/pledgie/pledgie.php', 'pledgie_active');
- Addon::unregisterHook('plugin_settings', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/pledgie/pledgie.php', 'pledgie_addon_settings_post');
}
function pledgie_addon_settings(&$a,&$s) {
diff --git a/public_server/public_server.php b/public_server/public_server.php
index 422746f0..2c096568 100644
--- a/public_server/public_server.php
+++ b/public_server/public_server.php
@@ -1,7 +1,7 @@
*/
@@ -141,8 +141,8 @@ function public_server_login($a,$b) {
);
}
-function public_server_plugin_admin_post ( &$a ) {
- check_form_security_token_redirectOnErr('/admin/plugins/publicserver', 'publicserver');
+function public_server_addon_admin_post ( &$a ) {
+ check_form_security_token_redirectOnErr('/admin/addons/publicserver', 'publicserver');
$expiredays = (( x($_POST, 'expiredays') ) ? notags(trim($_POST['expiredays'] )) : '');
$expireposts = (( x($_POST, 'expireposts') ) ? notags(trim($_POST['expireposts'] )) : '');
$nologin = (( x($_POST, 'nologin') ) ? notags(trim($_POST['nologin'] )) : '');
@@ -157,7 +157,7 @@ function public_server_plugin_admin_post ( &$a ) {
Config::set( 'public_server','flagpostsexpire',$flagpostsexpire );
info( t('Settings saved').EOL );
}
-function public_server_plugin_admin ( &$a, &$o) {
+function public_server_addon_admin ( &$a, &$o) {
$token = get_form_security_token("publicserver");
$t = get_markup_template( "admin.tpl", "addon/public_server");
$o = replace_macros($t, [
diff --git a/qcomment/qcomment.php b/qcomment/qcomment.php
index 2e1783c0..447f8abf 100644
--- a/qcomment/qcomment.php
+++ b/qcomment/qcomment.php
@@ -9,7 +9,7 @@
*
* Provides a set of text "snippets" which can be inserted into a comment window by clicking on them.
* First enable the addon in the system admin panel.
- * Then each person can tailor their choice of words in Settings->Plugin Settings in the Qcomment
+ * Then each person can tailor their choice of words in Settings->Addon Settings in the Qcomment
* pane. Initially no qcomments are provided, but on viewing the settings page, a default set of
* of words is suggested. These can be accepted (click Submit) or edited first. Each text line represents
* a different qcomment.
@@ -23,15 +23,15 @@ use Friendica\Core\Addon;
use Friendica\Core\PConfig;
function qcomment_install() {
- Addon::registerHook('plugin_settings', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings');
- Addon::registerHook('plugin_settings_post', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings_post');
+ Addon::registerHook('addon_settings', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings');
+ Addon::registerHook('addon_settings_post', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings_post');
}
function qcomment_uninstall() {
- Addon::unregisterHook('plugin_settings', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/qcomment/qcomment.php', 'qcomment_addon_settings_post');
}
diff --git a/randplace/randplace.php b/randplace/randplace.php
index a6a639ec..96e549a6 100644
--- a/randplace/randplace.php
+++ b/randplace/randplace.php
@@ -1,7 +1,7 @@
*
@@ -11,7 +11,7 @@
* Addons are registered with the system through the admin
* panel.
*
- * When registration is detected, the system calls the plugin
+ * When registration is detected, the system calls the addon
* name_install() function, located in 'addon/name/name.php',
* where 'name' is the name of the addon.
* If the addon is removed from the configuration list, the
@@ -25,7 +25,7 @@ function randplace_install() {
/**
*
- * Our demo plugin will attach in three places.
+ * Our demo addon will attach in three places.
* The first is just prior to storing a local post.
*
*/
@@ -34,14 +34,14 @@ function randplace_install() {
/**
*
- * Then we'll attach into the plugin settings page, and also the
+ * Then we'll attach into the addon settings page, and also the
* settings post hook so that we can create and update
* user preferences.
*
*/
- Addon::registerHook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
- Addon::registerHook('plugin_settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
+ Addon::registerHook('addon_settings', 'addon/randplace/randplace.php', 'randplace_settings');
+ Addon::registerHook('addon_settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("installed randplace");
}
@@ -58,8 +58,8 @@ function randplace_uninstall() {
*/
Addon::unregisterHook('post_local', 'addon/randplace/randplace.php', 'randplace_post_hook');
- Addon::unregisterHook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/randplace/randplace.php', 'randplace_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("removed randplace");
@@ -74,7 +74,7 @@ function randplace_post_hook($a, &$item) {
* An item was posted on the local system.
* We are going to look for specific items:
* - A status post by a profile owner
- * - The profile owner must have allowed our plugin
+ * - The profile owner must have allowed our addon
*
*/
@@ -142,7 +142,7 @@ function randplace_settings_post($a,$post) {
/**
*
- * Called from the Plugin Setting form.
+ * Called from the Addon Setting form.
* Add our own settings info to the page.
*
*/
@@ -169,7 +169,7 @@ function randplace_settings(&$a,&$s) {
$s .= '
';
diff --git a/twitter/twitter.php b/twitter/twitter.php
index 1b475801..a33415d8 100644
--- a/twitter/twitter.php
+++ b/twitter/twitter.php
@@ -33,7 +33,7 @@
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/
-/* Twitter Plugin for Friendica
+/* Twitter Addon for Friendica
*
* Author: Tobias Diekershoff
* tobias.diekershoff@gmx.net
@@ -41,7 +41,7 @@
* License:3-clause BSD license
*
* Configuration:
- * To use this plugin you need a OAuth Consumer key pair (key & secret)
+ * To use this addon you need a OAuth Consumer key pair (key & secret)
* you can get it from Twitter at https://twitter.com/apps
*
* Register your Friendica site as "Client" application with "Read & Write" access
@@ -53,9 +53,9 @@
* $a->config['twitter']['consumerkey'] = 'your consumer_key here';
* $a->config['twitter']['consumersecret'] = 'your consumer_secret here';
*
- * To activate the plugin itself add it to the $a->config['system']['addon']
+ * To activate the addon itself add it to the $a->config['system']['addon']
* setting. After this, your user can configure their Twitter account settings
- * from "Settings -> Plugin Settings".
+ * from "Settings -> Addon Settings".
*
* Requirements: PHP5, curl [Slinky library]
*/
@@ -109,8 +109,8 @@ function twitter_uninstall()
// old setting - remove only
Addon::unregisterHook('post_local_end', 'addon/twitter/twitter.php', 'twitter_post_hook');
- Addon::unregisterHook('plugin_settings', 'addon/twitter/twitter.php', 'twitter_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/twitter/twitter.php', 'twitter_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/twitter/twitter.php', 'twitter_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/twitter/twitter.php', 'twitter_settings_post');
}
function twitter_check_item_notification(App $a, &$notification_data)
@@ -301,7 +301,7 @@ function twitter_settings(App $a, &$s)
/* * *
* make some nice form
*/
- $s .= '
' . t('At this Friendica instance the Twitter plugin was enabled but you have not yet connected your account to your Twitter account. To do so click the button below to get a PIN from Twitter which you have to copy into the input box below and submit the form. Only your public posts will be posted to Twitter.') . '
';
+ $s .= '
' . t('At this Friendica instance the Twitter addon was enabled but you have not yet connected your account to your Twitter account. To do so click the button below to get a PIN from Twitter which you have to copy into the input box below and submit the form. Only your public posts will be posted to Twitter.') . '
";
$o .= call_user_func($a->argv[1].'_widget_help');
diff --git a/windowsphonepush/windowsphonepush.php b/windowsphonepush/windowsphonepush.php
index 377d2cd4..861bb7af 100644
--- a/windowsphonepush/windowsphonepush.php
+++ b/windowsphonepush/windowsphonepush.php
@@ -10,7 +10,7 @@
* Pre-requisite: Windows Phone mobile device (at least WP 7.0)
* Friendica mobile app on Windows Phone
*
- * When plugin is installed, the system calls the plugin
+ * When addon is installed, the system calls the addon
* name_install() function, located in 'addon/name/name.php',
* where 'name' is the name of the addon.
* If the addon is removed from the configuration list, the
@@ -32,19 +32,19 @@ use Friendica\Model\User;
function windowsphonepush_install()
{
- /* Our plugin will attach in three places.
+ /* Our addon will attach in three places.
* The first is within cron - so the push notifications will be
* sent every 10 minutes (or whatever is set in crontab).
*/
Addon::registerHook('cron', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_cron');
- /* Then we'll attach into the plugin settings page, and also the
+ /* Then we'll attach into the addon settings page, and also the
* settings post hook so that we can create and update
- * user preferences. User shall be able to activate the plugin and
+ * user preferences. User shall be able to activate the addon and
* define whether he allows pushing first characters of item text
*/
- Addon::registerHook('plugin_settings', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings');
- Addon::registerHook('plugin_settings_post', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings_post');
+ Addon::registerHook('addon_settings', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings');
+ Addon::registerHook('addon_settings_post', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings_post');
logger("installed windowsphonepush");
}
@@ -55,8 +55,8 @@ function windowsphonepush_uninstall()
* during install. Don't delete data in table `pconfig`.
*/
Addon::unregisterHook('cron', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_cron');
- Addon::unregisterHook('plugin_settings', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/windowsphonepush/windowsphonepush.php', 'windowsphonepush_settings_post');
logger("removed windowsphonepush");
}
@@ -89,7 +89,7 @@ function windowsphonepush_settings_post($a, $post)
info(t('WindowsPhonePush settings updated.') . EOL);
}
-/* Called from the Plugin Setting form.
+/* Called from the Addon Setting form.
* Add our own settings info to the page.
*/
function windowsphonepush_settings(&$a, &$s)
@@ -115,7 +115,7 @@ function windowsphonepush_settings(&$a, &$s)
$s .= '
' . t('WindowsPhonePush Settings') . '
';
$s .= '
';
- $s .= '';
+ $s .= '';
$s .= '';
$s .= '
';
@@ -136,12 +136,12 @@ function windowsphonepush_settings(&$a, &$s)
return;
}
-/* Cron function used to regularly check all users on the server with active windowsphonepushplugin and send
+/* Cron function used to regularly check all users on the server with active windowsphonepushaddon and send
* notifications to the Microsoft servers and consequently to the Windows Phone device
*/
function windowsphonepush_cron()
{
- // retrieve all UID's for which the plugin windowsphonepush is enabled and loop through every user
+ // retrieve all UID's for which the addon windowsphonepush is enabled and loop through every user
$r = q("SELECT * FROM `pconfig` WHERE `cat` = 'windowsphonepush' AND `k` = 'enable' AND `v` = 1");
if (count($r)) {
foreach ($r as $rr) {
@@ -152,7 +152,7 @@ function windowsphonepush_cron()
// pushing only possible if device_url (the URI on Microsoft server) is available or not "NA" (which will be sent
// by app if user has switched the server setting in app - sending blank not possible as this would return an update error)
if (( $device_url == "" ) || ( $device_url == "NA" )) {
- // no Device-URL for the user availabe, but plugin is enabled --> write info to Logger
+ // no Device-URL for the user availabe, but addon is enabled --> write info to Logger
logger("WARN: windowsphonepush is enable for user " . $rr['uid'] . ", but no Device-URL is specified for the user.");
} else {
// retrieve the number of unseen items and the id of the latest one (if there are more than
@@ -393,7 +393,7 @@ function windowsphonepush_updatesettings()
return "Not Authenticated";
}
- // no updating if user hasn't enabled the plugin
+ // no updating if user hasn't enabled the addon
$enable = PConfig::get(local_user(), 'windowsphonepush', 'enable');
if (!$enable) {
return "Plug-in not enabled";
@@ -434,7 +434,7 @@ function windowsphonepush_updatecounterunseen()
return "Not Authenticated";
}
- // no updating if user hasn't enabled the plugin
+ // no updating if user hasn't enabled the addon
$enable = PConfig::get(local_user(), 'windowsphonepush', 'enable');
if (!$enable) {
return "Plug-in not enabled";
diff --git a/wppost/wppost.php b/wppost/wppost.php
index d73005a3..af371af1 100644
--- a/wppost/wppost.php
+++ b/wppost/wppost.php
@@ -26,8 +26,8 @@ function wppost_uninstall() {
// obsolete - remove
Addon::unregisterHook('post_local_end', 'addon/wppost/wppost.php', 'wppost_send');
- Addon::unregisterHook('plugin_settings', 'addon/wppost/wppost.php', 'wppost_settings');
- Addon::unregisterHook('plugin_settings_post', 'addon/wppost/wppost.php', 'wppost_settings_post');
+ Addon::unregisterHook('addon_settings', 'addon/wppost/wppost.php', 'wppost_settings');
+ Addon::unregisterHook('addon_settings_post', 'addon/wppost/wppost.php', 'wppost_settings_post');
}
@@ -86,7 +86,7 @@ function wppost_settings(&$a,&$s) {
$s .= '
diff --git a/piwik/piwik.php b/piwik/piwik.php
index ddba2dd9..326b931f 100644
--- a/piwik/piwik.php
+++ b/piwik/piwik.php
@@ -1,13 +1,13 @@
* Author: Klaus Weidenbach
*/
/* Piwik Analytics Plugin for Friendica
*
* Author: Tobias Diekershoff
* tobias.diekershoff@gmx.net
@@ -35,19 +35,19 @@ use Friendica\Core\Config;
function piwik_install() {
Addon::registerHook('page_end', 'addon/piwik/piwik.php', 'piwik_analytics');
- logger("installed piwik plugin");
+ logger("installed piwik addon");
}
function piwik_uninstall() {
Addon::unregisterHook('page_end', 'addon/piwik/piwik.php', 'piwik_analytics');
- logger("uninstalled piwik plugin");
+ logger("uninstalled piwik addon");
}
function piwik_analytics($a,&$b) {
/*
* styling of every HTML block added by this plugin is done in the
* associated CSS file. We just have to tell Friendica to get it
* into the page header.
*/
@@ -85,7 +85,7 @@ function piwik_analytics($a,&$b) {
$b .= "
";
}
}
-function piwik_plugin_admin (&$a, &$o) {
+function piwik_addon_admin (&$a, &$o) {
$t = get_markup_template( "admin.tpl", "addon/piwik/" );
$o = replace_macros( $t, [
'$submit' => t('Save Settings'),
@@ -95,7 +95,7 @@ function piwik_plugin_admin (&$a, &$o) {
'$async' => ['async', t('Asynchronous tracking'), Config::get('piwik','async' ), ''],
]);
}
-function piwik_plugin_admin_post (&$a) {
+function piwik_addon_admin_post (&$a) {
$url = ((x($_POST, 'baseurl')) ? notags(trim($_POST['baseurl'])) : '');
$id = ((x($_POST, 'siteid')) ? trim($_POST['siteid']) : '');
$optout = ((x($_POST, 'optout')) ? trim($_POST['optout']) : '');
@@ -1,13 +1,13 @@
* Author: Klaus Weidenbach
*/
-/* Piwik Analytics Plugin for Friendica
+/* Piwik Analytics Addon for Friendica
*
* Author: Tobias Diekershoff
@@ -35,19 +35,19 @@ use Friendica\Core\Config;
function piwik_analytics($a,&$b) {
/*
- * styling of every HTML block added by this plugin is done in the
+ * styling of every HTML block added by this addon is done in the
* associated CSS file. We just have to tell Friendica to get it
* into the page header.